function M = GetVisualizationMovie(Ys, C, limit)
%
% Convert intermediate visualization maps to a MATLAB movie
% Input:
%    Ys       intermediate visualization maps
%    C        class label
%    limit    boolean parameter specifying using adaptive limit in the
%             movie frames
% Output:
%    M        the MATLAB movie object which can be displayed by calling
%             movie(M)
%
adaptive_limit=false;
if ~exist('limit', 'var') || isempty(limit)
    adaptive_limit=true;
end
n = length(Ys);
figure('Position', [40,40, 800, 800]);
for i=1:n
    Y = Ys{i};
    if ~exist('C', 'var') || isempty(C)
        scatter(Y(:,1), Y(:,2), 'filled');
    else
        gscatter(Y(:,1), Y(:,2), C, [], '.o*+xsd^v<>ph', 5);
    end
    axis equal;
    if adaptive_limit
        limit = max(abs(Y(:)));
        xlim([-limit,limit]);
        ylim([-limit,limit]);
    end
    title(['iter=',num2str(i)]);
    M(i) = getframe;
end