function [Y, Ys] = fphssne(X, alpha, c, nSeed, max_iter, disp_step, tol, verbose)
%
% Compute visualization map for multi-dimensional input using Heavy-tailed 
% Symmetric Stochastic Neighbor Embedding and the fixed-point algorithm
% 
% Y = fphssne(X);
%   Compute the visualization map using default settings
%   Input X: n x d
%   Output Y: n x 2
%
% Y = fphssne(X, alpha, c);
%   Using the power family of heavy-tailed embedding functions
%   Default alpha=1, c=1 (Student t-distribution with single freedom)
%
% Y = fphssne(X, alpha, c, nSeed, max_iter, disp_step, tol, verbose);
%   Specifying more details
%   nSeed         random seed for initializing Y (default 0)
%   max_iter      maximum iterations (default 1000)
%   disp_step     iterval of statistics output (default 10) 
%   tol           convergence tolerance of Y (default 1e-4)
%   verbose       displaying verbosity (default true)
%
% [Y,YS] = fphssne(...);
%    Also return the intermediate visualization maps
%    Ys is a cell array of size (max_iter,1)
%
% Zhirong Yang, January 4, 2010

if ~exist('alpha', 'var') || isempty(alpha)
    alpha = 1;
end
if ~exist('c', 'var') || isempty(c)
    c = 1;
end
if ~exist('nSeed', 'var')
    nSeed = 0;
end
if ~exist('max_iter', 'var')
    max_iter = 1000;
end
if ~exist('disp_step', 'var')
    disp_step = 10;
end
if ~exist('tol', 'var')
    tol = 1e-4;
end
if ~exist('verbose', 'var')
    verbose = true;
end

X = zscore(X);

perplexity = 30;
P = x2p(X, perplexity, 1e-5);

[Y,Ys] = fphssne_p(P, alpha, c, nSeed, max_iter, disp_step, tol, verbose);